/*****************************************************
 * Display - Klasse fuer 20x4 LCD Display            *
 * nach Michael Majunke und Oliver Bendig            *
 *****************************************************
 * Klasse......: Display                             *
 * Funktion....: Klasse zum leichten Ansprechen      *
 *               eines LCDs an einem Mikrocontroller *
 *               nach Michael Majunke                *
 *               Programmversion 0.92.2 nach 	     *
 *               Oliver Bendig                       *
 * Sprache.....: C++                                 *
 * Compiler....: mind. GNU gcc 2.95.3 unter Linux    *
 * Autor.......: Oliver Bendig
 * Datum.......: 12.06.2002                          *
 *****************************************************
 * Beispiel:                                         *
 * ------------------------------------------------- *
 * 
 *	#include "Display.h"
 *
 *	int main(void)
 *	{
 *		class Display Disp;
 *		int key;
 *		Disp.init("/dev/ttyS0");
 *		Disp.clear();
 *		Disp.setLight(LIGHT_ON);
 *		Disp.center(1, "Dies");
 *		Disp.center(2, "ist");
 *		Disp.center(3, "ein");
 *		Disp.center(4, "Test!!!");
 *		Disp.home();
 *		Disp.defUC(0, "FFFFFFFFFFFFFFFF");
 *		Disp.print("-");
 *		Disp.ascii(0x00);
 *		Disp.setLEDs(LED_BLINK, LED_OFF, LED_BLINK);
 *		while(1)
 *		{
 *			if ((key = Disp.getKeys()) > 0) printf("%d", key);
 *			if (key == 5 || key == -1) break;
 *		}
 *		printf("\n");
 *		Disp.clear();
 *		Disp.quit();
 *   		return 0;
 *	} 
 * ------------------------------------------------- *
 *	#include "Display.h"
 *
 *	int main(void)
 *	{
 *	    Display *Disp = NULL;
 *	    Disp = new Display;
 *	    Disp->init("/dev/ttyS0");
 *	    Disp->setLight(LIGHT_ON);
 *	    Disp->center(1, "Muh!");
 *	    Disp->center(2, "Muh!!");
 *	    Disp->quit();
 *	    return 0;
 *	}
 *****************************************************/

#ifndef _DISPLAY_H
#define _DISPLAY_H

#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdio.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>
#include <termio.h>
#include <sys/time.h>
#include <sys/types.h>

enum ENUMSELTYPE { stread, stwrite };
enum LIGHT { LIGHT_OFF, LIGHT_ON, LIGHT_AUTO };
enum LED   { LED_OFF, LED_ON, LED_BLINK };

class Display
{
    private:
	int fd;
	
    public:
	Display();
	int init(char *);
	int home();
	int setLEDs(enum LED, enum LED, enum LED);
	int getKeys();
	int gotoxy(int x, int y);
	int setLight(enum LIGHT);
	int print(char *);
	int center(int, char *);
	int ascii(int);
	int clear();
	int clearScreen();
	int clearLEDs();
	int defUC(int, char *);
	int quit();
};

#endif